Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(259)

Unified Diff: chrome/browser/autofill/android/personal_data_manager_android.h

Issue 2287513002: [Payments] Show name and address when selecting a CC billing address. (Closed)
Patch Set: Fixed error Created 4 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/autofill/android/personal_data_manager_android.h
diff --git a/chrome/browser/autofill/android/personal_data_manager_android.h b/chrome/browser/autofill/android/personal_data_manager_android.h
index 0f7920a517de05ff4e6cddaf39e3970de1d90807..ad8f0257f474b94c3dbfb8e7346afcaf46c19c85 100644
--- a/chrome/browser/autofill/android/personal_data_manager_android.h
+++ b/chrome/browser/autofill/android/personal_data_manager_android.h
@@ -61,11 +61,13 @@ class PersonalDataManagerAndroid : public PersonalDataManagerObserver {
// Gets the labels for the profiles to suggest to the user. These labels are
// useful for distinguishing the profiles from one another.
//
// The labels never contain the full name, email address, or phone numbers.
// All other fields are included in the label.
base::android::ScopedJavaLocalRef<jobjectArray> GetProfileLabelsToSuggest(
JNIEnv* env,
- const base::android::JavaParamRef<jobject>& unused_obj);
+ const base::android::JavaParamRef<jobject>& unused_obj,
+ jboolean include_name);
// Returns the label of the given profile for PaymentRequest. This label does
// not contain the full name or the email address. All other fields are
@@ -266,6 +268,7 @@ class PersonalDataManagerAndroid : public PersonalDataManagerObserver {
base::android::ScopedJavaLocalRef<jobjectArray> GetProfileLabels(
JNIEnv* env,
bool address_only,
+ bool include_name,
std::vector<AutofillProfile*> profiles);
// Pointer to the java counterpart.
@@ -61,11 +61,13 @@ class PersonalDataManagerAndroid : public PersonalDataManagerObserver {
// useful for distinguishing the profiles from one another.
//
- // The labels never contain the full name, email address, or phone numbers.
- // All other fields are included in the label.
+ // The labels never contain the email address, or phone numbers. The
+ // |include_name| argument controls whether the name is included. All other
+ // fields are included in the label.
base::android::ScopedJavaLocalRef<jobjectArray> GetProfileLabelsToSuggest(
JNIEnv* env,

Powered by Google App Engine
This is Rietveld 408576698